@@ -4,11 +4,15 @@ from packaging import version
 from d3graph.d3graph import (
     vec2adjmat,
     adjmat2vec,
+    make_graph,
+    json_create,
+    adjmat2dict,
+    data_checks,
     )
 
 __author__ = 'Erdogan Tasksen'
 __email__ = 'erdogant@gmail.com'
-__version__ = '2.3.2'
+__version__ = '2.3.5'
 
 # import jinja2
 # if version.parse(jinja2.__version__) > version.parse("2.11.3"):
