@@ -83,8 +83,8 @@ class d3graph:
         set_logger(verbose=verbose)
         # Setup configurations
         self.config = {}
-        self.config['network_collision'] = collision
-        self.config['network_charge'] = charge * -1
+        self.config['collision'] = collision
+        self.config['charge'] = -abs(charge)
         self.config['slider'] = slider
         # Set paths
         self.config['curpath'] = os.path.dirname(os.path.abspath(__file__))
@@ -144,13 +144,14 @@ class d3graph:
         self.write_html(json_data, overwrite=overwrite)
         # Open the webbrowser
         if self.config['showfig']:
-            self._showfig(self.config['filepath'])
+            self.showfig(self.config['filepath'])
             # webbrowser.open(os.path.abspath(self.config['filepath']), new=2)
         # Return
         return self.G
 
     @staticmethod
-    def _showfig(filepath: str, sleep: float = 0.5) -> None:
+    def showfig(filepath: str, sleep: float = 0.5) -> None:
+        """Show figure."""
         # Sleeping is required to prevent overlapping windows
         time.sleep(sleep)
         file_location = os.path.abspath(filepath)
@@ -328,7 +329,7 @@ class d3graph:
         elif 'numpy' in str(type(color)):
             color = _get_hexcolor(color, cmap=self.config['cmap'])
         elif isinstance(color, str) and color == 'cluster':
-            color, group, _ = self.get_cluster_color(node_names=node_names)
+            color, group, _ = self.get_cluster_color(node_names=node_names, color=color)
         elif isinstance(color, str):
             color = np.array([color] * nodecount)
         elif color is None:
@@ -409,7 +410,7 @@ class d3graph:
         logger.info('Number of unique nodes: %.0d', len(self.node_properties.keys()))
 
     # compute clusters
-    def get_cluster_color(self, node_names: list = None) -> tuple:
+    def get_cluster_color(self, node_names: list = None, color: str = '#000080') -> tuple:
         """Clustering of graph labels.
 
         Parameters
@@ -427,6 +428,10 @@ class d3graph:
         import networkx as nx
         from community import community_louvain
         if node_names is None: node_names = [*self.node_properties.keys()]
+        if not isinstance(color, str): color = '#000080'
+        # Set defaults
+        labx = {key: {'name': key, 'color': color, 'group': '-1'} for i, key in
+                enumerate(node_names)}
 
         df = adjmat2vec(self.adjmat.copy())
         G = nx.from_pandas_edgelist(df, edge_attr=True, create_using=nx.MultiGraph)
@@ -436,8 +441,13 @@ class d3graph:
         # Extract clusterlabels
         y = list(map(lambda x: cluster_labels.get(x), cluster_labels.keys()))
         hex_colors, _ = cm.fromlist(y, cmap=self.config['cmap'], scheme='hex')
-        labx = {key: {'name': key, 'color': hex_colors[i], 'group': cluster_labels.get(key)} for i, key in
-                enumerate(cluster_labels.keys())}
+        # Update colors and labels based on clustering
+        for i, key in enumerate(cluster_labels.keys()):
+            labx.get(key)['group'] = cluster_labels.get(key)
+            labx.get(key)['color'] = hex_colors[i]
+
+        # labx = {key: {'name': key, 'color': hex_colors[i], 'group': cluster_labels.get(key)} for i, key in
+        #         enumerate(cluster_labels.keys())}
 
         # return
         color = np.array(list(map(lambda x: labx.get(x)['color'], node_names)))
@@ -468,7 +478,7 @@ class d3graph:
         self.config['slider'] = [int(min_slider), int(max_slider)]
         logger.info('Slider range is set to [%g, %g]' % (self.config['slider'][0], self.config['slider'][1]))
 
-    def graph(self, adjmat, scaler: str = 'zscore') -> None:
+    def graph(self, adjmat, group: str = 'cluster', scaler: str = 'zscore') -> None:
         """Process the adjacency matrix and set all properties to default.
 
         Description
@@ -480,6 +490,10 @@ class d3graph:
         ----------
         adjmat : pd.DataFrame()
             Adjacency matrix (symmetric). Values > 0 are edges.
+        group : list of strings (default: 'cluster')
+            Grouping (and coloring) of the nodes.
+            * 'cluster' : Colours are based on the community distance clusters.
+            * None: All nodes will have the same color (auto generated).
         scaler : str, (default: 'zscore')
             Scale the edge-width using the following scaler:
             'zscore' : Scale values to Z-scores.
@@ -520,7 +534,7 @@ class d3graph:
         # Set default edge properties
         self.set_edge_properties(scaler=scaler)
         # Set default node properties
-        self.set_node_properties(scaler=scaler)
+        self.set_node_properties(color=group, scaler=scaler)
 
     def write_html(self, json_data, overwrite: bool = True) -> None:
         """Write html.
@@ -540,18 +554,20 @@ class d3graph:
                    'title'        : self.config['network_title'],
                    'width'        : self.config['figsize'][0],
                    'height'       : self.config['figsize'][1],
-                   'charge'       : self.config['network_charge'],
+                   'charge'       : self.config['charge'],
                    'edge_distance': self.config['edge_distance'],
                    'min_slider'   : self.config['slider'][0],
                    'max_slider'   : self.config['slider'][1],
                    'directed'     : self.config['directed'],
-                   'collision'    : self.config['network_collision'],
+                   'collision'    : self.config['collision'],
                    'slider_comment_start' : show_slider[0],
                    'slider_comment_stop'  : show_slider[1],
                    }
-
-        jinja_env = Environment(loader=PackageLoader(package_name=__name__, package_path='d3js'))
-        # jinja_env = Environment(loader=PackageLoader(package_name='d3graph', package_path='d3js'))
+        # Issue14: https://github.com/erdogant/d3graph/issues/14
+        try:
+            jinja_env = Environment(loader=PackageLoader(package_name=__name__, package_path='d3js'))
+        except:
+            jinja_env = Environment(loader=PackageLoader(package_name='d3graph', package_path='d3js'))
         index_template = jinja_env.get_template('index.html.j2')
         index_file = Path(self.config['filepath'])
         logger.info(f'Write to path: [{index_file.absolute()}]')
@@ -610,13 +626,13 @@ class d3graph:
             target = ['node F', 'node B', 'node J', 'node F', 'node F', 'node M', 'node M', 'node A']
             weight = [5.56, 0.5, 0.64, 0.23, 0.9, 3.28, 0.5, 0.45]
             adjmat = vec2adjmat(source, target, weight=weight)
-            return adjmat
+            return adjmat, None
         elif network == 'bigbang':
             source = ['Penny', 'Penny', 'Amy', 'Bernadette', 'Bernadette', 'Sheldon', 'Sheldon', 'Sheldon', 'Rajesh']
             target = ['Leonard', 'Amy', 'Bernadette', 'Rajesh', 'Howard', 'Howard', 'Leonard', 'Amy', 'Penny']
             weight = [5, 3, 2, 2, 5, 2, 3, 5, 2]
             adjmat = vec2adjmat(source, target, weight=weight)
-            return adjmat
+            return adjmat, None
         elif network == 'karate':
             import scipy
             if version.parse(scipy.__version__) < version.parse('1.8.0'):
